package io.data2viz.charts.chart.mark

import io.data2viz.charts.chart.Chart
import io.data2viz.charts.chart.mark.internal.EmptyMarkImpl
import io.data2viz.charts.core.ChartDSL
import io.data2viz.charts.dimension.Dimension

/**
 * Add an [EmptyMarkImpl] to the current [Chart]. An [EmptyMark] is a Mark with no sign, it is used to display
 * axes only.
 *
 * @param x The [Dimension] for the X axis, this dimension can be continuous or discrete.
 * @param y The [Dimension] for the Y axis, this dimension can be continuous or discrete.
 * @param init The initialization lambda for this [Mark].
 */
public fun <DOMAIN, XVAL, YVAL> Chart<DOMAIN>.empty(
    x: Dimension<DOMAIN, XVAL>,
    y: Dimension<DOMAIN, YVAL>,
    init: EmptyMark<DOMAIN, XVAL, YVAL>.() -> Unit = {}
): Unit =
    addMark { markIndex -> EmptyMarkImpl(markIndex, dataset, x, y, init, config.mark, config.x, config.y) }


/**
 * An utility empty mark, can have a X and a Y axis, but does not draw anything.
 */
@ChartDSL
public interface EmptyMark<DOMAIN, XVAL, YVAL> : MarkXY<DOMAIN, XVAL, YVAL>
