package io.data2viz.charts.chart.mark

import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.LayoutPosition
import io.data2viz.charts.core.Zone
import io.data2viz.charts.layout.DrawingZone

/**
 * If a [Mark] has some specificities (large size, custom layout, custom stacking...) it may needs to implement
 * HasCustomTooltip to provide additional information on how to "plug" the tooltip on a given [Datum].
 *
 * @param datum, the [Datum] on which the tooltip needs to be displayed
 * @return the tooltip "anchor" position, or null if no tooltip can be placed for the given [Datum]
 */
public interface HasCustomTooltip<DOMAIN> {

    /**
     * Return the [TooltipPosition] if available for th given [Datum] and the current [DrawingZone].
     */
    public fun getTooltipPosition(datum: Datum<DOMAIN>, drawingZone: DrawingZone): TooltipPosition?
}

/**
 * Holds a [Tooltip] layout information, the [zone] is the zone on which the tooltip is expected to "anchor",
 * the [layout] is where the tooltip is expected to be placed from that zone.
 *
 * The [Tooltip] will then place itself from these informations
 */
public data class TooltipPosition(

    /**
     * The zone on which the [Tooltip] is attached.
     */
    public val zone: Zone,

    /**
     * The expected [LayoutPosition] for the [Tooltip], relative to its zone.
     */
    public val layout: LayoutPosition
)
