package io.data2viz.charts.config

import io.data2viz.charts.chart.Chart
import io.data2viz.charts.core.Padding
import io.data2viz.color.Color
import io.data2viz.format.Locale

/**
 * [Chart] basic configuration.
 */
public interface ChartBasicConfig {

    /**
     * Enable "performance mode": better [Chart] reactivity even with a lot of data but requires more graphic memory.
     *
     * Most of the time, performance mode can be disabled without experiencing any kind of issue, but when dealing
     * with very large datasets, or when using lots of graphical components, it is interesting to try
     * performance mode if you want to kee user interactions very smooth.
     *
     * - false: (default mode) less memory consumption but the framerate when refreshing screen (interactions...) may
     * not be optimal.
     * - true: (performance mode) increase the memory requirements but help maintain a good framerate even with
     * very large datasets.
     */
    @Deprecated("No longer settable")
    public var performanceMode: Boolean

    /**
     * The [Padding] for the [Chart].
     */
    public var padding: Padding

    /**
     * The number formatting locale
     */
    public var numberLocale: Locale

    /**
     * The date formatting locale
     */
    public var timeLocale: io.data2viz.timeFormat.Locale

//    public var dropShadow: Boolean
//    public var dropShadowStroke: Color
//    public var dropShadowFill: Color

    /**
     * The background color for the [Chart], this color must have a alpha channel value of 100%.
     */
    public var backgroundColor: Color

    @Suppress("DEPRECATION")
    @Deprecated("No longer settable")
    public var splitCanvas: Boolean
        get() = performanceMode
        set(value) {
            performanceMode = value
        }

    @Suppress("UNUSED_PARAMETER")
    @Deprecated(message = "Unused configuration property. Remove it.")
    public var ChartBasicConfig.enableMarks: Boolean
        get() = true
        set(value) {}

}


