package io.data2viz.charts.config

import io.data2viz.charts.chart.internal.CursorImpl
import io.data2viz.charts.core.*
import io.data2viz.charts.core.CursorType
import io.data2viz.charts.core.Stroke
import io.data2viz.charts.layout.DrawingZone
import io.data2viz.geom.Point

/**
 * A decorator lambda is called for the cursor, use this to draw custom cursors.
 *
 * @param selectedData the current [SelectedDatum]
 * @param position the expected position where the cursor should appear (relative to the [drawingZone] coordinates)
 * @param drawingZone the drawing zone on which to draw the decorator
 */
public typealias CursorDecorator<DOMAIN> = (selectedData: SelectedDatum<DOMAIN>?, position: Point, drawingZone: DrawingZone) -> Unit

/**
 * The configuration interface for a [CursorImpl].
 */
public interface CursorConfig : Stroke {

    /**
     * Show / hide the [CursorImpl].
     */
    public var show: Boolean

    /**
     * Type of [CursorImpl]: horizontal, vertical or crosshair.
     */
    public var type: CursorType

    /**
     * The cursor decorator lambda will be called on cursor display, use this to draw custom cursors.
     */
    @ExperimentalCharts
    public var cursorDecorator: CursorDecorator<*>?

}
