package io.data2viz.charts.config

import io.data2viz.charts.core.Font
import io.data2viz.charts.core.LegendLayout
import io.data2viz.charts.core.LegendPosition
import io.data2viz.charts.core.LegendVisibility
import io.data2viz.charts.core.Padding
import io.data2viz.charts.core.Stroke
import io.data2viz.color.Color

/**
 * The configuration for the [Legend].
 */
public interface LegendConfig: Font, Stroke {

    /**
     * Padding of your legend box.
     */
    public var padding: Padding

    /**
     * Legend background color.
     */
    public var backgroundColor: Color?

    /**
     * Show or hide the Legend.
     * Warning, the current default behavior is [LegendVisibility.Hide], it may change to [LegendVisibility.Auto] when
     * Legend will be not be "experimental" anymore.
     */
    public var show: LegendVisibility

    /**
     * The [layout] details how to display the legend.
     */
    public var layout: LegendLayout

    /**
     * The [position] details where to display the legend.
     */
    public var position: LegendPosition

}
