package io.data2viz.charts.config.configs

import io.data2viz.charts.config.ChartConfig
import io.data2viz.charts.config.configuration
import io.data2viz.color.Colors
import io.data2viz.color.col
import io.data2viz.math.pct

/**
 * Light themed [ChartConfig]: use light colors and less screen space than other configurations.
 */
public val lightConfig: ChartConfig
    get() = configuration {

        fontColor = "#707070".col
        strokeColor = "#999999".col

        chart {
//        dropShadowStroke = "#999999".col.withAlpha(40.pct)
//        dropShadowFill = "#999999".col.withAlpha(30.pct)
        }


        mark {
            markersSize = 30.0

            strokeColors = listOf("#999999".col)
            fills = listOf("#DDDDDD".col.withAlpha(60.pct))

            strokeColorsHighlight = strokeColors.toList()
            fillsHighlight = fills.toList()
            strokeWidthHighlight = 3.0

            strokeColorsSelect = strokeColors.toList()
            fillsSelect = fills.toList()
            strokeWidthSelect = 3.0
        }


        tooltip {
            backgroundColor = "#F6F6F6".col.withAlpha(80.pct)
        }


        cursor {
            strokeColor = "#5577DD".col
        }


        zoom {
            fill = Colors.Web.orangered.withAlpha(30.pct)
            strokeColor = null
            strokeWidth = null
        }


        selection {
            fill = Colors.Web.lightblue.withAlpha(30.pct)
            strokeColor = null
            strokeWidth = null
        }


        xAxis {
            enableTitle = true
            tickPadding = 3.0
            enableGridLines = false
            gridLinesColor = "#BBBBBB".col
            gridLinesDashed = doubleArrayOf(2.0, 4.0)
            alternateBackgroundColor = "#DDDDDD".col.withAlpha(30.pct)
        }

        yAxis {
            enableAxisLine = false
            enableTicks = false
            enableGridLines = true
            gridLinesColor = "#BBBBBB".col
            gridLinesDashed = doubleArrayOf(2.0, 4.0)
            alternateBackgroundColor = "#DDDDDD".col.withAlpha(30.pct)
        }
    }
