package io.data2viz.charts.core

import io.data2viz.charts.chart.Chart
import io.data2viz.geom.Point
import io.data2viz.geom.RectGeom
import kotlin.math.pow

/**
 * A [Zone] shaped as a circle, used to indicate interactive zones in a [Chart].
 *
 * @see Zone
 */
public data class CircleZone(

    override val center: Point,

    /**
     * This [Zone]'s circle radius
     */
    val radius: Double

) : Zone {

    private val radiusSquared = radius * radius
    private val offset = Point(radius, radius)

    override fun contains(point: Point): Boolean {
        return (point.x - center.x).pow(2) + (point.y - center.y).pow(2) <= radiusSquared
    }

    override fun getAnchorPoint(layoutPosition: LayoutPosition): Point {
        return when (layoutPosition) {
            LayoutPosition.Top -> Point(center.x, center.y - radius)
            LayoutPosition.Right -> Point(center.x + radius, center.y)
            LayoutPosition.Bottom -> Point(center.x, center.y + radius)
            LayoutPosition.Left -> Point(center.x - radius, center.y)
        }
    }

    override val bounds: RectGeom = RectGeom(center - offset, center + offset)
}
