package io.data2viz.charts.core

/**
 * The display position of an element relative to the main charting zone.
 */
public enum class LayoutPosition {

    /**
     * Display the element on top of the main charting zone.
     */
    Top,

    /**
     * Display the element on the right of the main charting zone.
     */
    Right,

    /**
     * Display the element at the bottom of the main charting zone.
     */
    Bottom,

    /**
     * Display the element on the left of the main charting zone.
     */
    Left;

    internal val isTop: Boolean
        get() = this == Top

    internal val isBottom: Boolean
        get() = this == Bottom

    internal val isRight: Boolean
        get() = this == Right

    internal val isLeft: Boolean
        get() = this == Left

    internal val isTopOrBottom: Boolean
        get() = (isTop || isBottom)

    internal val isLeftOrRight: Boolean
        get() = (isLeft || isRight)

    internal val orientation: Orientation
        get() = if (isLeftOrRight) Orientation.Vertical else Orientation.Horizontal
}
