package io.data2viz.charts.core

/**
 * Internal layout of a [Legend] box.
 */
public enum class LegendLayout {

    /**
     * Default value, the [Legend] is displayed horizontally or vertically depending on which is best.
     */
    Auto,

    /**
     * The [Legend] is displayed vertically.
     */
    Vertical,

    /**
     * The [Legend] is displayed horizontally.
     */
    Horizontal;

    /**
     * Use the layout and the position to compute a Legend "orientation)
     */
    internal fun toOrientation(position: LegendPosition): Orientation = when (this) {
        Vertical        -> Orientation.Vertical
        Horizontal      -> Orientation.Horizontal
        Auto            -> when (position) {
            LegendPosition.Top      -> Orientation.Horizontal
            LegendPosition.Bottom   -> Orientation.Horizontal
            LegendPosition.Right    -> Orientation.Vertical
            LegendPosition.Left     -> Orientation.Vertical
            else                    -> error("This LegendLayout cannot be transformed into an Orientation.")
        }
    }
}
