package io.data2viz.charts.core

/**
 * Panning behavior, use it to authorize or restrict panning.
 */
public enum class PanMode {

    /**
     * Disable panning.
     */
    None,

    /**
     * Pan only allowed on X axis.
     */
    X,

    /**
     * Pan only allowed on Y axis.
     */
    Y,

    /**
     * Pan only allowed on X and Y axis.
     */
    XY;

    /**
     * Is pan on X allowed (X or XY pan)
     */
    internal val panX: Boolean
        get() = this == X || this == XY

    /**
     * Is pan on Y allowed (Y or XY pan)
     */
    internal val panY: Boolean
        get() = this == Y || this == XY

    /**
     * Is pan enabled (X, Y or XY)
     */
    internal val enabled: Boolean
        get() = this != None
}

