package io.data2viz.charts.core

import io.data2viz.charts.chart.mark.Mark

/**
 * Selection behaviors, define how to handle the selection of [Mark] symbols.
 */
public enum class SelectionMode {

    /**
     * Only select the value for the currently smallest selected mark
     */
    Single,

    /**
     * Allow selection of multiple marks
     */
    Multiple,

    /**
     * Disable [Mark] selection through user interaction, but you can still select it through the select() function.
     */
    Disabled,

    /**
     * Completely disable [Mark] selection, even through the select() function.
     */
    None;

    internal val enabled: Boolean
        get() = this != Disabled && this != None
}
