package io.data2viz.charts.core

import io.data2viz.charts.chart.mark.Mark

/**
 * Define when to trigger an event when interacting with a [Mark] sign, based on the cursor position.
 */
public enum class TriggerMode {

    /**
     * The nearest element is selected.
     */
    Nearest,

    /**
     * The element is selected only when passing over its "selection zone".
     * @see Zone
     */
    Hover,

    /**
     * Mainly used for X-aligned category-charts, highlight the nearest element in the current "column"
     */
    Column,

    /**
     * Mainly used for Y-aligned category-charts, highlight the nearest element in the current "row"
     */
    Row,

    /**
     * This default mode, will switch automatically to the best mode based on the chart configuration.
     * For example, if your chart is a Column chart, the mode will switch to TriggerMode.Column.
     */
    Auto
}
