package io.data2viz.charts.dimension

import io.data2viz.charts.core.Datum


/**
 * [Discrete] is a [Dimension] that is used to manage discrete values.
 * It is build by giving an "accessor" lambda that returns a discrete <VALUE> object from a given [Datum] of a <DOMAIN>.
 *
 * Use the [Chart.discrete] function to build a [Discrete] dimension.
 *
 * Examples:
 *  - val fruitsDimension = discrete( { domain.fruitName } )
 *  - val weatherDimension = discrete( { domain.weatherType } )
 *  - val students = discrete( { domain } )
 *  - val indexDimension = discrete( { indexInData } )
 */
public class Discrete<DOMAIN, VALUE>(
    accessor: Datum<DOMAIN>.() -> VALUE,
    init: Discrete<DOMAIN, VALUE>.() -> Unit = {}
) : DiscreteDimension<DOMAIN, VALUE>(accessor) {

    init {
        init()
    }
}
