package io.data2viz.charts.event

import io.data2viz.charts.chart.Chart
import io.data2viz.charts.chart.mark.RelativePoint
import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.SelectedDatum
import io.data2viz.charts.event.internal.EventController
import io.data2viz.geom.Point
import io.data2viz.geom.Rect
import io.data2viz.viz.EventPropagation

internal class EventContextImpl<DOMAIN>(
    ec: EventController<DOMAIN>,
    event: UserEvent,
    previousPosition: Point,

    // TODO the "dragzone" should be computed on request (from startmouse...)
    override val dragZone: Rect?,

    pointerZoomAction: ZoomAction?
) : EventContext<DOMAIN>, UserEvent by event {

    override val chart: Chart<DOMAIN> by lazy { ec.chart }

    override val currentRelativePosition: RelativePoint by lazy { ec.positionToRelativePoint(event.currentPosition) }

    override val selectedData: List<SelectedDatum<DOMAIN>> by lazy {
        ec.getIndexedData(event.currentPosition, dragZone)
    }

    /**
     * If there is a specific pointer zoom (like mouse wheel at a point or dual-touch pinch around a point),
     * then take this as the zoom action, else define a zoom action from other parameters.
     */
    override val zoomAction: ZoomAction by lazy {
        pointerZoomAction ?: ec.getZoomActionFromDragZone(currentRelativePosition, dragZone)
    }

    override val panAction: PanAction by lazy {
        ec.getPanActionFromMovement(event.currentPosition, previousPosition)
    }

    override val zoomZone: RectWithHandlers? by lazy { ec.getZoomZoneFromConstraints(dragZone) }

    override val data: List<Datum<DOMAIN>> by lazy { selectedData.map { it.datum }.toSet().toList() }

    public override fun stopEventPropagation() { _eventPropagation = EventPropagation.Stop }

    public override fun forceEventPropagation() { _eventPropagation = EventPropagation.Continue }

    internal val eventPropagation
        get() = _eventPropagation

    private var _eventPropagation = EventPropagation.Continue
}
