package io.data2viz.charts.event

import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.SelectedDatum

/**
 * A "highlight event" is generally triggered when a user interacts with a [Mark] by rolling over it.
 *
 * @param selectedData the map of [Datum] to highlight for each markIndex
 * @param data the list of [Datum] to highlight.
 */
public class HighlightEvent<DOMAIN> public constructor(
    public val selectedData: List<SelectedDatum<DOMAIN>>,
) : ChartEvent {

    public constructor(data: Collection<Datum<DOMAIN>>) : this(data.map { SelectedDatum(it, it.indexOfSeries, 0) })

    override var preventDefault: Boolean = false

    public val data: List<Datum<DOMAIN>> by lazy { selectedData.map { it.datum }.toSet().toList() }
}


