package io.data2viz.charts.event

import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.SelectedDatum

/**
 * Instantiate a [SelectionAddEvent] from a [Collection] of [Datum]
 */
public fun <DOMAIN> SelectionAddEvent(data: Collection<Datum<DOMAIN>>): SelectionAddEvent<DOMAIN> =
    SelectionAddEvent(data.map { SelectedDatum(it, it.indexOfSeries, 0) })

/**
 * A "selection add event" is generally triggered when a user interacts with a [Mark] by clicking on it.
 *
 * @param selectedData the map of [Datum] to add to selection
 */
public class SelectionAddEvent<DOMAIN> public constructor(
    public override val selectedData: Collection<SelectedDatum<DOMAIN>>
) : SelectionEvent<DOMAIN> {

    public override var preventDefault: Boolean = false

    public override val data: List<Datum<DOMAIN>> by lazy { selectedData.map { it.datum }.toSet().toList() }
}
