package io.data2viz.charts.event

import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.SelectedDatum

/**
 * Instantiate a [SelectionRemoveEvent] from a [Collection] of [Datum]
 */
public fun <DOMAIN> SelectionRemoveEvent(data: Collection<Datum<DOMAIN>>): SelectionRemoveEvent<DOMAIN> =
    SelectionRemoveEvent(data.map { SelectedDatum(it, it.indexOfSeries, 0) })

/**
 * A "selection remove event" is generally triggered when a user interacts with a [Mark] by clicking on it.
 *
 * @param selectedData the map of [Datum] to unselect
 */
public class SelectionRemoveEvent<DOMAIN> public constructor(
    public override val selectedData: Collection<SelectedDatum<DOMAIN>>
) : SelectionEvent<DOMAIN> {

    public override var preventDefault: Boolean = false

    public override val data: List<Datum<DOMAIN>> by lazy { selectedData.map { it.datum }.toSet().toList() }
}
