package io.data2viz.charts.layout

import io.data2viz.geom.Point
import io.data2viz.geom.Size
import io.data2viz.viz.HasChildren


/**
 * Screen space on which you can draw, a [DrawingZone] is generally given when calling draw functions so the user
 * don't have to think about layering, or absolute positioning, the given [DrawingZone] is already placed and sized
 * correctly.
 */
public interface DrawingZone: HasChildren {

    /**
     * Size of this [DrawingZone]: contentSize = Size(contentWidth, contentHeight).
     */
    public val contentSize: Size

    /**
     * Width of this [DrawingZone].
     */
    public val contentWidth: Double

    /**
     * Height of this [DrawingZone].
     */
    public val contentHeight: Double

    /**
     * Absolute position of this [DrawingZone] (its top-left coordinates in screen position).
     */
    public val absolutePosition: Point
}

