package io.data2viz.charts.logging

import io.data2viz.timeFormat.format
import kotlinx.datetime.Clock

/**
 * The entry point to get KLoggers.
 */
public object KLogging {

    /**
     * Create a KLogger using a name. The name is used in the log message.
     * The name is also a way of filtering logs at runtime. This is why
     * it's a good idea to use package+class names for loggers to allow
     * an hierarchical filtering of  logs.
     */
    public fun logger(name: String): KLogger = KLogger(name)

}
private val formatter = format("%I:%M:%S.%L")
private var lastLog = Clock.System.now().toEpochMilliseconds()

private const val showDuration = false

private fun timeInfo(): String =
    if (showDuration) {
        val now = Clock.System.now().toEpochMilliseconds()
        val diff = "${now - lastLog} ms".padStart(5, ' ')
        lastLog = now
        diff }
    else
        formatter(Clock.System.now())


/**
 * Information Logger.
 **/
public class KLogger(public val name: String) {

    /**
     * Print a message on the console. This message type is "verbose".
     * TODO Inline before release
     */
    internal fun verbose(message: String){
        println("$name ${timeInfo()}:: $message")  //TODO Remove and inline function for release
    }

    /**
     * Measure the time to process a [block] lambda and print the message with the elapsed time.
     * TODO Inline before release
     */
    public fun verbose(message: String, block: () -> Unit){
        val before = Clock.System.now().toEpochMilliseconds()       //TODO Remove and inline function for release
        block()                                                     //TODO KEEP and inline function for release
        val after = Clock.System.now().toEpochMilliseconds()        //TODO Remove and inline function for release
        println("$name ${timeInfo()}:: ${after-before} ms $message")//TODO Remove and inline function for release
    }

    /**
     * Print a message on the console. This message type is "debug".
     */
    public fun debug(message: String){
        println("$name ${timeInfo()}:: $message")    }

    /**
     * Print a message on the console. This message type is "warn".
     */
    public fun warn(message: String){
        println("$name ${timeInfo()}:: $message")    }

}

