package io.data2viz.charts.chart.mark

import io.data2viz.charts.chart.chart
import io.data2viz.charts.chart.discrete
import io.data2viz.charts.chart.internal.ChartImpl
import io.data2viz.charts.chart.mark.internal.AreaMarkImpl
import io.data2viz.charts.chart.mark.internal.BarMarkImpl
import io.data2viz.charts.chart.quantitative
import io.data2viz.charts.core.RectZone
import io.data2viz.viz.HeadlessVizContainer
import kotlin.test.Test
import kotlin.test.assertEquals


class TestMarkXY {

    @Test
    fun testEventZoneForAreaMark() {
        val vizContainer = HeadlessVizContainer()

        val chart = vizContainer.chart(listOf(1.0, 2.0, 3.0)){
            val x = discrete({domain.toInt()})
            val y = quantitative({domain})
            area(x,y)
        } as ChartImpl<Double>

        val areaMarkImpl = chart.marks[0] as AreaMarkImpl<Double,Int, Double>
        val eventZones = areaMarkImpl.getEventZones(chart.drawingZones.selectionLayer, chart.dataset)
        assertEquals(3, eventZones.size)
    }

    @Test
    fun testEventZoneForBarMark() {
        val vizContainer = HeadlessVizContainer()

        val chart = vizContainer.chart(listOf(1.0, 2.0, 3.0)){
            val year        = discrete( { domain.toInt() } )
            val population  = quantitative( { domain } )
            bar(population,year)
        } as ChartImpl<Double>

        val barMarkImpl = chart.marks[0] as BarMarkImpl<Double,Int, Double>
        val zones = barMarkImpl
            .getEventZones(chart.drawingZones.selectionLayer, chart.dataset)
            .map { it.zone }
        assertEquals(3, zones.filterIsInstance<RectZone>().size)
    }



}
