@file:Suppress("invisible_reference", "invisible_member")

package io.data2viz.charts.chart


import io.data2viz.charts.chart.internal.ChartImpl
import io.data2viz.charts.chart.mark.MarkX
import io.data2viz.charts.chart.mark.MarkY
import io.data2viz.charts.chart.mark.plot
import io.data2viz.charts.viz.VizContainer
import io.data2viz.charts.viz.newVizContainer
import io.data2viz.geom.Size
import javafx.application.Platform
import javafx.scene.Scene
import javafx.scene.layout.Pane
import javafx.stage.Stage
import junit.framework.Assert.assertFalse
import org.junit.Before
import org.junit.Test
import org.testfx.framework.junit.ApplicationTest
import org.testfx.util.WaitForAsyncUtils
import kotlin.test.assertTrue


const val appSize = 800.0

class TestTransformJFX : ApplicationTest() {

    lateinit var viz: VizContainer
    lateinit var stage: Stage

    override fun start(stage: Stage) {
        this.stage = stage
    }

    @Before
    fun beforeEachTest() {
        println("beforeEachTest")
        fxThread {
            println("runLater")
            val pane = Pane()
            viz = pane.newVizContainer().apply { size = Size(appSize, appSize) }
            val scene = Scene(pane, appSize, appSize)
            stage.scene = scene
            stage.show()
        }
        WaitForAsyncUtils.waitForFxEvents()
    }

    @Test
    fun notChildByDefault() {
        fxThread {
            val data = listOf(1.0, 2.0, 3.0)
            val chart = viz.chart(data) {
                val oneTime = quantitative({ domain })
                val twoTime = quantitative({ domain * 2 })
                plot(oneTime, twoTime)
            } as ChartImpl
            assertFalse((chart.marks.first() as MarkX<*, *>).x.isChild)
        }
    }

    @Test
    fun childIfSameDimension() {
        fxThread {
            val data = listOf(1.0, 2.0, 3.0)
            val chart = viz.chart(data) {
                val oneTime = quantitative({ domain })
                val twoTime = quantitative({ domain * 2 })
                plot(oneTime, twoTime)
                plot(oneTime, twoTime)
            } as ChartImpl
            assertFalse((chart.marks[0] as MarkX<*, *>).x.isChild)
            assertTrue((chart.marks[1] as MarkX<*, *>).x.isChild)
            assertTrue((chart.marks[1] as MarkY<*, *>).y.isChild)
        }
    }

    @Test
    fun childIfChildDimension() {
        fxThread {
            val data = listOf(1.0, 2.0, 3.0)
            val chart = viz.chart(data) {
                val oneTime = quantitative({ domain })
                val twoTime = quantitative({ domain * 2 })
                plot(oneTime, twoTime)
                plot(oneTime.child({ domain * 2 }), twoTime)
            } as ChartImpl
            assertFalse((chart.marks[0] as MarkX<*, *>).x.isChild)
            assertTrue((chart.marks[1] as MarkX<*, *>).x.isChild)
            assertTrue((chart.marks[1] as MarkY<*, *>).y.isChild)
        }
    }

}
